@@ -154,7 +154,7 @@ KDiff3App::KDiff3App(QWidget* pParent, const QString& name, KDiff3Part* pKDiff3P
     // ProgressProxy will otherwise emit no-ops to disconnected boost signals.
     if(g_pProgressDialog == nullptr)
     {
-        g_pProgressDialog = std::make_shared<ProgressDialog>(this, statusBar());
+        g_pProgressDialog = new ProgressDialog(this, statusBar());
         g_pProgressDialog->setStayHidden(true);
     }
 
@@ -168,7 +168,7 @@ KDiff3App::KDiff3App(QWidget* pParent, const QString& name, KDiff3Part* pKDiff3P
     m_pOptionDialog->readOptions(KSharedConfig::openConfig());
 
     // Option handling: Only when pParent==0 (no parent)
-    int argCount = KDiff3Shell::getParser()->optionNames().count() + KDiff3Shell::getParser()->positionalArguments().count();
+    qint32 argCount = KDiff3Shell::getParser()->optionNames().count() + KDiff3Shell::getParser()->positionalArguments().count();
     bool hasArgs = !isPart() && argCount > 0;
     if(hasArgs) {
         QString s;
@@ -407,7 +407,9 @@ void KDiff3App::slotFocusChanged(QWidget* old, QWidget* now)
     Q_UNUSED(now);
     Q_UNUSED(old);
 
-    Q_EMIT updateAvailabilities();
+    qCDebug(kdiffMain) << "[KDiff3App::slotFocusChanged] old = " << old << ", new =" << now;
+    //This needs to be called after the focus change is complete
+    QMetaObject::invokeMethod(this, &KDiff3App::updateAvailabilities, Qt::QueuedConnection);
 }
 
 // Do file comparision.
@@ -580,12 +582,8 @@ void KDiff3App::completeInit(const QString& fn1, const QString& fn2, const QStri
 
 KDiff3App::~KDiff3App()
 {
-    /*
-        Qt uses parent for memory management and event hierachy this is the only way to
-        by pass auto cleanup. That is needed thanks to the wordwrap helper threads using
-        DiffTextWindow pointers which must be std::shared_ptr.
-    */
-    g_pProgressDialog->setParent(nullptr);
+    g_pProgressDialog->cancel(ProgressDialog::eExit);
+
     // Prevent spurious focus change signals from Qt from being picked up by KDiff3App during destruction.
     QObject::disconnect(qApp, &QApplication::focusChanged, this, &KDiff3App::slotFocusChanged);
 };
@@ -636,9 +634,7 @@ void KDiff3App::initActions(KActionCollection* ac)
     editFind->setStatusTip(i18n("Search for a string"));
     editFindNext = KStandardAction::findNext(this, &KDiff3App::slotEditFindNext, ac);
     editFindNext->setStatusTip(i18n("Search again for the string"));
-    /*   FIXME figure out how to implement this action
-       viewToolBar = KStandardAction::showToolbar(this, &KDiff3App::slotViewToolBar, ac);
-       viewToolBar->setStatusTip(i18n("Enables/disables the toolbar")); */
+
     viewStatusBar = KStandardAction::showStatusbar(this, &KDiff3App::slotViewStatusBar, ac);
     viewStatusBar->setStatusTip(i18n("Enables/disables the statusbar"));
     KStandardAction::keyBindings(this, &KDiff3App::slotConfigureKeys, ac);
@@ -790,7 +786,7 @@ bool KDiff3App::queryClose()
 
     if(m_bOutputModified)
     {
-        int result = KMessageBox::warningYesNoCancel(this,
+        qint32 result = KMessageBox::warningYesNoCancel(this,
                                                      i18n("The merge result has not been saved."),
                                                      i18nc("Error dialog caption", "Warning"),
                                                      KGuiItem(i18n("Save && Quit")),
@@ -812,7 +808,7 @@ bool KDiff3App::queryClose()
 
     if(m_pDirectoryMergeWindow->isDirectoryMergeInProgress())
     {
-        int result = KMessageBox::warningYesNo(this,
+        qint32 result = KMessageBox::warningYesNo(this,
                                                i18n("You are currently doing a folder merge. Are you sure, you want to abort?"),
                                                i18nc("Error dialog caption", "Warning"),
                                                KStandardGuiItem::quit(),
@@ -908,8 +904,8 @@ void KDiff3App::slotFilePrint()
     //printDialog.setMinMax(0,0);
     printDialog->setFromTo(0, 0);
 
-    int currentFirstLine = m_pDiffTextWindow1->getFirstLine();
-    int currentFirstD3LIdx = m_pDiffTextWindow1->convertLineToDiff3LineIdx(currentFirstLine);
+    qint32 currentFirstLine = m_pDiffTextWindow1->getFirstLine();
+    qint32 currentFirstD3LIdx = m_pDiffTextWindow1->convertLineToDiff3LineIdx(currentFirstLine);
 
     // do some printer initialization
     printer.setFullPage(false);
@@ -922,11 +918,11 @@ void KDiff3App::slotFilePrint()
         RLPainter painter(&printer, m_pOptions->m_bRightToLeftLanguage, width(), Utils::getHorizontalAdvance(fontMetrics(),'W'));
 
         QPaintDevice* pPaintDevice = painter.device();
-        int dpiy = pPaintDevice->logicalDpiY();
-        int columnDistance = qRound((0.5 / 2.54) * dpiy); // 0.5 cm between the columns
+        qint32 dpiy = pPaintDevice->logicalDpiY();
+        qint32 columnDistance = qRound((0.5 / 2.54) * dpiy); // 0.5 cm between the columns
 
-        int columns = m_bTripleDiff ? 3 : 2;
-        int columnWidth = (pPaintDevice->width() - (columns - 1) * columnDistance) / columns;
+        qint32 columns = m_bTripleDiff ? 3 : 2;
+        qint32 columnWidth = (pPaintDevice->width() - (columns - 1) * columnDistance) / columns;
 
         QFont f = m_pOptions->defaultFont();
         f.setPointSizeF(f.pointSizeF() - 1); // Print with slightly smaller font.
@@ -935,11 +931,11 @@ void KDiff3App::slotFilePrint()
 
         QString topLineText = i18n("Top line");
 
-        //int headerWidth = fm.width( m_sd1->getAliasName() + ", "+topLineText+": 01234567" );
-        int headerLines = Utils::getHorizontalAdvance(fm, m_sd1->getAliasName() + ", " + topLineText + ": 01234567") / columnWidth + 1;
+        //qint32 headerWidth = fm.width( m_sd1->getAliasName() + ", "+topLineText+": 01234567" );
+        qint32 headerLines = Utils::getHorizontalAdvance(fm, m_sd1->getAliasName() + ", " + topLineText + ": 01234567") / columnWidth + 1;
 
-        int headerMargin = headerLines * fm.height() + 3; // Text + one horizontal line
-        int footerMargin = fm.height() + 3;
+        qint32 headerMargin = headerLines * fm.height() + 3; // Text + one horizontal line
+        qint32 footerMargin = fm.height() + 3;
 
         QRect view(0, headerMargin, pPaintDevice->width(), pPaintDevice->height() - (headerMargin + footerMargin));
         QRect view1(0 * (columnWidth + columnDistance), view.top(), columnWidth, view.height());
@@ -961,7 +957,7 @@ void KDiff3App::slotFilePrint()
         if(m_bTripleDiff && m_pDiffTextWindow3 != nullptr)
             totalNofLines = std::max(totalNofLines, m_pDiffTextWindow3->getNofLines());
 
-        QList<int> pageList; // = printer.pageList();
+        QList<qint32> pageList; // = printer.pageList();
 
         bool bPrintCurrentPage = false;
         bool bFirstPrintedPage = false;
@@ -973,7 +969,7 @@ void KDiff3App::slotFilePrint()
 
         if(printer.printRange() == QPrinter::AllPages) {
             pageList.clear();
-            for(int i = 0; i < totalNofPages; ++i)
+            for(qint32 i = 0; i < totalNofPages; ++i)
             {
                 pageList.push_back(i + 1);
             }
@@ -982,7 +978,7 @@ void KDiff3App::slotFilePrint()
         {
             pageList.clear();
 
-            int from = printer.fromPage(), to = printer.toPage();
+            qint32 from = printer.fromPage(), to = printer.toPage();
             /*
                 Per Qt docs QPrinter::fromPage and QPrinter::toPage return 0 to indicate they are not set.
                 Account for this and other invalid settings the user may try.
@@ -992,7 +988,7 @@ void KDiff3App::slotFilePrint()
             if(to == 0 || to > totalNofPages) to = totalNofPages;
             if(from > to) to = from;
 
-            for(int i = from; i <= to; ++i)
+            for(qint32 i = from; i <= to; ++i)
             {
                 pageList.push_back(i);
             }
@@ -1015,15 +1011,15 @@ void KDiff3App::slotFilePrint()
             }
         }
 
-        int page = 1;
+        qint32 page = 1;
 
-        ProgressProxy pp;
-        pp.setMaxNofSteps(totalNofPages);
-        QList<int>::iterator pageListIt = pageList.begin();
+        ProgressScope pp;
+        ProgressProxy::setMaxNofSteps(totalNofPages);
+        QList<qint32>::iterator pageListIt = pageList.begin();
         for(;;) {
-            pp.setInformation(i18n("Printing page %1 of %2", page, totalNofPages), false);
-            pp.setCurrent(page - 1);
-            if(pp.wasCancelled())
+            ProgressProxy::setInformation(i18n("Printing page %1 of %2", page, totalNofPages), false);
+            ProgressProxy::setCurrent(page - 1);
+            if(ProgressProxy::wasCancelled())
             {
                 printer.abort();
                 break;
@@ -1121,28 +1117,6 @@ void KDiff3App::slotFileQuit()
     QApplication::exit(isFileSaved() || isDirComparison() ? 0 : 1);
 }
 
-void KDiff3App::slotViewToolBar()
-{
-    assert(viewToolBar != nullptr);
-    slotStatusMsg(i18n("Toggling toolbar..."));
-    m_pOptions->setToolbarState(viewToolBar->isChecked());
-    ///////////////////////////////////////////////////////////////////
-    // turn Toolbar on or off
-    if(toolBar(MAIN_TOOLBAR_NAME) != nullptr)
-    {
-        if(!m_pOptions->isToolBarVisable())
-        {
-            toolBar(MAIN_TOOLBAR_NAME)->hide();
-        }
-        else
-        {
-            toolBar(MAIN_TOOLBAR_NAME)->show();
-        }
-    }
-
-    slotStatusMsg(i18n("Ready."));
-}
-
 void KDiff3App::slotViewStatusBar()
 {
     slotStatusMsg(i18n("Toggle the statusbar..."));
